var files =
[
    [ "aqt.c", "aqt_8c.html", "aqt_8c" ],
    [ "bhunt_search_test.c", "bhunt__search__test_8c.html", "bhunt__search__test_8c" ],
    [ "cairo.c", "cairo_8c.html", "cairo_8c" ],
    [ "cd.c", "cd_8c.html", "cd_8c" ],
    [ "cd.h", "cd_8h.html", "cd_8h" ],
    [ "cddll.h", "cddll_8h.html", "cddll_8h" ],
    [ "cdexpert.c", "cdexpert_8c.html", "cdexpert_8c" ],
    [ "cdmulti.c", "cdmulti_8c.html", "cdmulti_8c" ],
    [ "cdsimple.c", "cdsimple_8c.html", "cdsimple_8c" ],
    [ "cdtest.c", "cdtest_8c.html", "cdtest_8c" ],
    [ "cdtext.c", "cdtext_8c.html", "cdtext_8c" ],
    [ "cgm.c", "cgm_8c.html", "cgm_8c" ],
    [ "color16.c", "color16_8c.html", "color16_8c" ],
    [ "config.java", "config_8java.html", [
      [ "config", "classplplot_1_1core_1_1config.html", "classplplot_1_1core_1_1config" ]
    ] ],
    [ "csa.c", "csa_8c.html", "csa_8c" ],
    [ "csa.h", "csa_8h.html", "csa_8h" ],
    [ "csadll.h", "csadll_8h.html", "csadll_8h" ],
    [ "defines.h", "defines_8h.html", "defines_8h" ],
    [ "delaunay.c", "delaunay_8c.html", "delaunay_8c" ],
    [ "delaunay.h", "delaunay_8h.html", "delaunay_8h" ],
    [ "deltaT-gen.c", "deltaT-gen_8c.html", "deltaT-gen_8c" ],
    [ "deltaT.h", "deltaT_8h.html", "deltaT_8h" ],
    [ "deltaT_test.c", "deltaT__test_8c.html", "deltaT__test_8c" ],
    [ "dirent_msvc.h", "dirent__msvc_8h.html", "dirent__msvc_8h" ],
    [ "disptab.h", "disptab_8h.html", "disptab_8h" ],
    [ "drivers.h", "drivers_8h.html", "drivers_8h" ],
    [ "dspline.c", "dspline_8c.html", "dspline_8c" ],
    [ "dspline.h", "dspline_8h.html", "dspline_8h" ],
    [ "dsplint.c", "dsplint_8c.html", "dsplint_8c" ],
    [ "dsplint.h", "dsplint_8h.html", "dsplint_8h" ],
    [ "gd.c", "gd_8c.html", "gd_8c" ],
    [ "hash.c", "hash_8c.html", "hash_8c" ],
    [ "hash.h", "hash_8h.html", "hash_8h" ],
    [ "istack.c", "istack_8c.html", "istack_8c" ],
    [ "istack.h", "istack_8h.html", "istack_8h" ],
    [ "lpi.c", "lpi_8c.html", "lpi_8c" ],
    [ "ltdl_win32.c", "ltdl__win32_8c.html", "ltdl__win32_8c" ],
    [ "ltdl_win32.h", "ltdl__win32_8h.html", "ltdl__win32_8h" ],
    [ "makedocstrings.py", "makedocstrings_8py.html", "makedocstrings_8py" ],
    [ "matrixInit.c", "matrixInit_8c.html", "matrixInit_8c" ],
    [ "mem.c", "mem_8c.html", null ],
    [ "metadefs.h", "metadefs_8h.html", "metadefs_8h" ],
    [ "moc_files.h", "moc__files_8h.html", null ],
    [ "mt19937ar.c", "mt19937ar_8c.html", "mt19937ar_8c" ],
    [ "mt19937ar.h", "mt19937ar_8h.html", "mt19937ar_8h" ],
    [ "csa/nan.h", "csa_2nan_8h.html", "csa_2nan_8h" ],
    [ "nn/nan.h", "nn_2nan_8h.html", "nn_2nan_8h" ],
    [ "nn.h", "nn_8h.html", "nn_8h" ],
    [ "nnai.c", "nnai_8c.html", "nnai_8c" ],
    [ "nncommon.c", "nncommon_8c.html", "nncommon_8c" ],
    [ "nndll.h", "nndll_8h.html", "nndll_8h" ],
    [ "nnpi.c", "nnpi_8c.html", "nnpi_8c" ],
    [ "ntk.c", "ntk_8c.html", "ntk_8c" ],
    [ "null.c", "null_8c.html", "null_8c" ],
    [ "pdf.c", "pdf_8c.html", "pdf_8c" ],
    [ "pdf.h", "pdf_8h.html", "pdf_8h" ],
    [ "pdfutils.c", "pdfutils_8c.html", "pdfutils_8c" ],
    [ "plaffine.c", "plaffine_8c.html", "plaffine_8c" ],
    [ "plarc.c", "plarc_8c.html", "plarc_8c" ],
    [ "plargs.c", "plargs_8c.html", "plargs_8c" ],
    [ "plbox.c", "plbox_8c.html", "plbox_8c" ],
    [ "plbuf.c", "plbuf_8c.html", "plbuf_8c" ],
    [ "plcairo_impl.c", "plcairo__impl_8c.html", "plcairo__impl_8c" ],
    [ "PLCallbackCT.java", "PLCallbackCT_8java.html", [
      [ "PLCallbackCT", "interfaceplplot_1_1core_1_1PLCallbackCT.html", "interfaceplplot_1_1core_1_1PLCallbackCT" ]
    ] ],
    [ "PLCallbackLabel.java", "PLCallbackLabel_8java.html", [
      [ "PLCallbackLabel", "interfaceplplot_1_1core_1_1PLCallbackLabel.html", "interfaceplplot_1_1core_1_1PLCallbackLabel" ]
    ] ],
    [ "PLCallbackMapform.java", "PLCallbackMapform_8java.html", [
      [ "PLCallbackMapform", "interfaceplplot_1_1core_1_1PLCallbackMapform.html", "interfaceplplot_1_1core_1_1PLCallbackMapform" ]
    ] ],
    [ "plConfig.h", "plConfig_8h.html", "plConfig_8h" ],
    [ "plcont.c", "plcont_8c.html", "plcont_8c" ],
    [ "plcore.c", "plcore_8c.html", "plcore_8c" ],
    [ "plcore.h", "plcore_8h.html", "plcore_8h" ],
    [ "plctrl.c", "plctrl_8c.html", "plctrl_8c" ],
    [ "plcvt.c", "plcvt_8c.html", "plcvt_8c" ],
    [ "pldebug.h", "pldebug_8h.html", "pldebug_8h" ],
    [ "plDevs.h", "plDevs_8h.html", "plDevs_8h" ],
    [ "pldll.h", "pldll_8h.html", "pldll_8h" ],
    [ "pldtik.c", "pldtik_8c.html", "pldtik_8c" ],
    [ "plevent.h", "plevent_8h.html", "plevent_8h" ],
    [ "plf2ops.c", "plf2ops_8c.html", "plf2ops_8c" ],
    [ "plfci-truetype.h", "plfci-truetype_8h.html", "plfci-truetype_8h" ],
    [ "plfci-type1.h", "plfci-type1_8h.html", "plfci-type1_8h" ],
    [ "plfill.c", "plfill_8c.html", "plfill_8c" ],
    [ "plframe.c", "plframe_8c.html", "plframe_8c" ],
    [ "Plframe.py", "Plframe_8py.html", "Plframe_8py" ],
    [ "plfreetype.c", "plfreetype_8c.html", "plfreetype_8c" ],
    [ "plfreetype.h", "plfreetype_8h.html", null ],
    [ "plgradient.c", "plgradient_8c.html", "plgradient_8c" ],
    [ "PLGraphicsIn.java", "PLGraphicsIn_8java.html", [
      [ "PLGraphicsIn", "classplplot_1_1core_1_1PLGraphicsIn.html", "classplplot_1_1core_1_1PLGraphicsIn" ]
    ] ],
    [ "plgridd.c", "plgridd_8c.html", "plgridd_8c" ],
    [ "plhershey-unicode.h", "plhershey-unicode_8h.html", "plhershey-unicode_8h" ],
    [ "plhist.c", "plhist_8c.html", "plhist_8c" ],
    [ "plimage.c", "plimage_8c.html", "plimage_8c" ],
    [ "pllegend.c", "pllegend_8c.html", "pllegend_8c" ],
    [ "plline.c", "plline_8c.html", "plline_8c" ],
    [ "plmap.c", "plmap_8c.html", "plmap_8c" ],
    [ "plmem.c", "plmem_8c.html", "plmem_8c" ],
    [ "plmeta.c", "plmeta_8c.html", "plmeta_8c" ],
    [ "plmetafile.c", "plmetafile_8c.html", "plmetafile_8c" ],
    [ "plot3d.c", "plot3d_8c.html", "plot3d_8c" ],
    [ "plpage.c", "plpage_8c.html", "plpage_8c" ],
    [ "plparseopts.f90", "plparseopts_8f90.html", "plparseopts_8f90" ],
    [ "plplot.d", "plplot_8d.html", "plplot_8d" ],
    [ "plplot.h", "plplot_8h.html", "plplot_8h" ],
    [ "plplot_config.h", "plplot__config_8h.html", "plplot__config_8h" ],
    [ "plplot_impl.c", "plplot__impl_8c.html", "plplot__impl_8c" ],
    [ "plplot_octaveOCTAVE_wrap.cxx", "plplot__octaveOCTAVE__wrap_8cxx.html", "plplot__octaveOCTAVE__wrap_8cxx" ],
    [ "plplot_parameters.h", "plplot__parameters_8h.html", "plplot__parameters_8h" ],
    [ "plplot_types.f90", "plplot__types_8f90.html", [
      [ "plplot_types", "classplplot__types.html", "classplplot__types" ]
    ] ],
    [ "plplot_widgetmodule.c", "plplot__widgetmodule_8c.html", "plplot__widgetmodule_8c" ],
    [ "plplotc.py", "plplotc_8py.html", "plplotc_8py" ],
    [ "plplotcmodulePYTHON_wrap.c", "plplotcmodulePYTHON__wrap_8c.html", "plplotcmodulePYTHON__wrap_8c" ],
    [ "plplotjavac.java", "plplotjavac_8java.html", [
      [ "plplotjavac", "classplplot_1_1core_1_1plplotjavac.html", "classplplot_1_1core_1_1plplotjavac" ]
    ] ],
    [ "plplotjavacConstants.java", "plplotjavacConstants_8java.html", [
      [ "plplotjavacConstants", "interfaceplplot_1_1core_1_1plplotjavacConstants.html", "interfaceplplot_1_1core_1_1plplotjavacConstants" ]
    ] ],
    [ "plplotjavacJAVA_wrap.c", "plplotjavacJAVA__wrap_8c.html", "plplotjavacJAVA__wrap_8c" ],
    [ "plplotjavacJNI.java", "plplotjavacJNI_8java.html", [
      [ "plplotjavacJNI", "classplplot_1_1core_1_1plplotjavacJNI.html", "classplplot_1_1core_1_1plplotjavacJNI" ]
    ] ],
    [ "plplotluacLUA_wrap.c", "plplotluacLUA__wrap_8c.html", "plplotluacLUA__wrap_8c" ],
    [ "plplotP.h", "plplotP_8h.html", "plplotP_8h" ],
    [ "plplotqt.h", "plplotqt_8h.html", null ],
    [ "plplotqt_smoke.h", "plplotqt__smoke_8h.html", "plplotqt__smoke_8h" ],
    [ "plplotter.c", "plplotter_8c.html", "plplotter_8c" ],
    [ "Plplotter_Init.c", "Plplotter__Init_8c.html", "Plplotter__Init_8c" ],
    [ "plqt.cpp", "plqt_8cpp.html", "plqt_8cpp" ],
    [ "plr.c", "plr_8c.html", "plr_8c" ],
    [ "plsdef.c", "plsdef_8c.html", "plsdef_8c" ],
    [ "plserver.c", "plserver_8c.html", "plserver_8c" ],
    [ "plserver.h", "plserver_8h.html", "plserver_8h" ],
    [ "plshade.c", "plshade_8c.html", "plshade_8c" ],
    [ "plstdio.c", "plstdio_8c.html", "plstdio_8c" ],
    [ "plstream.cc", "plstream_8cc.html", "plstream_8cc" ],
    [ "plstream.h", "plstream_8h.html", "plstream_8h" ],
    [ "PLStream.java", "PLStream_8java.html", [
      [ "PLStream", "classplplot_1_1core_1_1PLStream.html", "classplplot_1_1core_1_1PLStream" ]
    ] ],
    [ "plstripc.c", "plstripc_8c.html", "plstripc_8c" ],
    [ "plstrm.h", "plstrm_8h.html", "plstrm_8h" ],
    [ "plstubs.h", "plstubs_8h.html", "plstubs_8h" ],
    [ "plsym.c", "plsym_8c.html", "plsym_8c" ],
    [ "pltcl.c", "pltcl_8c.html", "pltcl_8c" ],
    [ "pltcl.h", "pltcl_8h.html", "pltcl_8h" ],
    [ "pltick.c", "pltick_8c.html", "pltick_8c" ],
    [ "pltime.c", "pltime_8c.html", "pltime_8c" ],
    [ "pltk.h", "pltk_8h.html", "pltk_8h" ],
    [ "Pltk_Init.c", "Pltk__Init_8c.html", "Pltk__Init_8c" ],
    [ "pltkd.h", "pltkd_8h.html", [
      [ "TkDev", "structTkDev.html", "structTkDev" ]
    ] ],
    [ "pltkwd.h", "pltkwd_8h.html", "pltkwd_8h" ],
    [ "plunicode-type1.h", "plunicode-type1_8h.html", "plunicode-type1_8h" ],
    [ "plvect.c", "plvect_8c.html", "plvect_8c" ],
    [ "plvpor.c", "plvpor_8c.html", "plvpor_8c" ],
    [ "plwind.c", "plwind_8c.html", "plwind_8c" ],
    [ "plxwd.h", "plxwd_8h.html", "plxwd_8h" ],
    [ "ps.c", "ps_8c.html", "ps_8c" ],
    [ "ps.h", "ps_8h.html", "ps_8h" ],
    [ "pstex.c", "pstex_8c.html", "pstex_8c" ],
    [ "psttf.cc", "psttf_8cc.html", "psttf_8cc" ],
    [ "qsastime.c", "qsastime_8c.html", "qsastime_8c" ],
    [ "qsastime.h", "qsastime_8h.html", "qsastime_8h" ],
    [ "qsastime_extra.c", "qsastime__extra_8c.html", "qsastime__extra_8c" ],
    [ "qsastime_extra.h", "qsastime__extra_8h.html", "qsastime__extra_8h" ],
    [ "qsastime_test.c", "qsastime__test_8c.html", "qsastime__test_8c" ],
    [ "qsastime_testlib.c", "qsastime__testlib_8c.html", "qsastime__testlib_8c" ],
    [ "qsastimedll.h", "qsastimedll_8h.html", "qsastimedll_8h" ],
    [ "qsastimeP.h", "qsastimeP_8h.html", "qsastimeP_8h" ],
    [ "qt.cpp", "qt_8cpp.html", "qt_8cpp" ],
    [ "qt.h", "qt_8h.html", "qt_8h" ],
    [ "sc3d.c", "sc3d_8c.html", "sc3d_8c" ],
    [ "sccont.c", "sccont_8c.html", "sccont_8c" ],
    [ "scstubs.c", "scstubs_8c.html", "scstubs_8c" ],
    [ "sfstubsf95.f90", "sfstubsf95_8f90.html", [
      [ "plplot_str", "classplplot__str.html", "classplplot__str" ],
      [ "plplotp", "classplplotp.html", [
        [ "plcont", "interfaceplplotp_1_1plcont.html", "interfaceplplotp_1_1plcont" ],
        [ "plimagefr", "interfaceplplotp_1_1plimagefr.html", "interfaceplplotp_1_1plimagefr" ],
        [ "plshade", "interfaceplplotp_1_1plshade.html", "interfaceplplotp_1_1plshade" ],
        [ "plshades", "interfaceplplotp_1_1plshades.html", "interfaceplplotp_1_1plshades" ],
        [ "plvect", "interfaceplplotp_1_1plvect.html", "interfaceplplotp_1_1plvect" ]
      ] ],
      [ "plcont", "interfaceplplotp_1_1plcont.html", "interfaceplplotp_1_1plcont" ],
      [ "plvect", "interfaceplplotp_1_1plvect.html", "interfaceplplotp_1_1plvect" ],
      [ "plshade", "interfaceplplotp_1_1plshade.html", "interfaceplplotp_1_1plshade" ],
      [ "plshades", "interfaceplplotp_1_1plshades.html", "interfaceplplotp_1_1plshades" ],
      [ "plimagefr", "interfaceplplotp_1_1plimagefr.html", "interfaceplplotp_1_1plimagefr" ],
      [ "plplot_graphics", "classplplot__graphics.html", [
        [ "plgraphicsin", "structplplot__graphics_1_1plgraphicsin.html", "structplplot__graphics_1_1plgraphicsin" ]
      ] ],
      [ "plgraphicsin", "structplplot__graphics_1_1plgraphicsin.html", "structplplot__graphics_1_1plgraphicsin" ],
      [ "plplot", "classplplot.html", "classplplot" ],
      [ "pladv", "interfaceplplot_1_1pladv.html", "interfaceplplot_1_1pladv" ],
      [ "plbin", "interfaceplplot_1_1plbin.html", "interfaceplplot_1_1plbin" ],
      [ "plbop", "interfaceplplot_1_1plbop.html", "interfaceplplot_1_1plbop" ],
      [ "plbtime", "interfaceplplot_1_1plbtime.html", "interfaceplplot_1_1plbtime" ],
      [ "plcalc_world", "interfaceplplot_1_1plcalc__world.html", "interfaceplplot_1_1plcalc__world" ],
      [ "plclear", "interfaceplplot_1_1plclear.html", "interfaceplplot_1_1plclear" ],
      [ "plcol0", "interfaceplplot_1_1plcol0.html", "interfaceplplot_1_1plcol0" ],
      [ "plcol1", "interfaceplplot_1_1plcol1.html", "interfaceplplot_1_1plcol1" ],
      [ "plcolorbar", "interfaceplplot_1_1plcolorbar.html", "interfaceplplot_1_1plcolorbar" ],
      [ "plconfigtime", "interfaceplplot_1_1plconfigtime.html", "interfaceplplot_1_1plconfigtime" ],
      [ "plcpstrm", "interfaceplplot_1_1plcpstrm.html", "interfaceplplot_1_1plcpstrm" ],
      [ "plctime", "interfaceplplot_1_1plctime.html", "interfaceplplot_1_1plctime" ],
      [ "plend1", "interfaceplplot_1_1plend1.html", "interfaceplplot_1_1plend1" ],
      [ "plenv", "interfaceplplot_1_1plenv.html", "interfaceplplot_1_1plenv" ],
      [ "pleop", "interfaceplplot_1_1pleop.html", "interfaceplplot_1_1pleop" ],
      [ "plerrx", "interfaceplplot_1_1plerrx.html", "interfaceplplot_1_1plerrx" ],
      [ "plerry", "interfaceplplot_1_1plerry.html", "interfaceplplot_1_1plerry" ],
      [ "plfamadv", "interfaceplplot_1_1plfamadv.html", "interfaceplplot_1_1plfamadv" ],
      [ "plfill", "interfaceplplot_1_1plfill.html", "interfaceplplot_1_1plfill" ],
      [ "plfill3", "interfaceplplot_1_1plfill3.html", "interfaceplplot_1_1plfill3" ],
      [ "plflush", "interfaceplplot_1_1plflush.html", "interfaceplplot_1_1plflush" ],
      [ "plfont", "interfaceplplot_1_1plfont.html", "interfaceplplot_1_1plfont" ],
      [ "plfontld", "interfaceplplot_1_1plfontld.html", "interfaceplplot_1_1plfontld" ],
      [ "plgchr", "interfaceplplot_1_1plgchr.html", "interfaceplplot_1_1plgchr" ],
      [ "plgcmap1_range", "interfaceplplot_1_1plgcmap1__range.html", "interfaceplplot_1_1plgcmap1__range" ],
      [ "plgcol0", "interfaceplplot_1_1plgcol0.html", "interfaceplplot_1_1plgcol0" ],
      [ "plgcol0a", "interfaceplplot_1_1plgcol0a.html", "interfaceplplot_1_1plgcol0a" ],
      [ "plgcolbg", "interfaceplplot_1_1plgcolbg.html", "interfaceplplot_1_1plgcolbg" ],
      [ "plgcolbga", "interfaceplplot_1_1plgcolbga.html", "interfaceplplot_1_1plgcolbga" ],
      [ "plgcompression", "interfaceplplot_1_1plgcompression.html", "interfaceplplot_1_1plgcompression" ],
      [ "plgdidev", "interfaceplplot_1_1plgdidev.html", "interfaceplplot_1_1plgdidev" ],
      [ "plgdiori", "interfaceplplot_1_1plgdiori.html", "interfaceplplot_1_1plgdiori" ],
      [ "plgdiplt", "interfaceplplot_1_1plgdiplt.html", "interfaceplplot_1_1plgdiplt" ],
      [ "plgetcursor", "interfaceplplot_1_1plgetcursor.html", "interfaceplplot_1_1plgetcursor" ],
      [ "plgfam", "interfaceplplot_1_1plgfam.html", "interfaceplplot_1_1plgfam" ],
      [ "plgfci", "interfaceplplot_1_1plgfci.html", "interfaceplplot_1_1plgfci" ],
      [ "plgfont", "interfaceplplot_1_1plgfont.html", "interfaceplplot_1_1plgfont" ],
      [ "plglevel", "interfaceplplot_1_1plglevel.html", "interfaceplplot_1_1plglevel" ],
      [ "plgpage", "interfaceplplot_1_1plgpage.html", "interfaceplplot_1_1plgpage" ],
      [ "plgra", "interfaceplplot_1_1plgra.html", "interfaceplplot_1_1plgra" ],
      [ "plgradient", "interfaceplplot_1_1plgradient.html", "interfaceplplot_1_1plgradient" ],
      [ "plgriddata", "interfaceplplot_1_1plgriddata.html", "interfaceplplot_1_1plgriddata" ],
      [ "plgspa", "interfaceplplot_1_1plgspa.html", "interfaceplplot_1_1plgspa" ],
      [ "plgstrm", "interfaceplplot_1_1plgstrm.html", "interfaceplplot_1_1plgstrm" ],
      [ "plgvpd", "interfaceplplot_1_1plgvpd.html", "interfaceplplot_1_1plgvpd" ],
      [ "plgvpw", "interfaceplplot_1_1plgvpw.html", "interfaceplplot_1_1plgvpw" ],
      [ "plgxax", "interfaceplplot_1_1plgxax.html", "interfaceplplot_1_1plgxax" ],
      [ "plgyax", "interfaceplplot_1_1plgyax.html", "interfaceplplot_1_1plgyax" ],
      [ "plgzax", "interfaceplplot_1_1plgzax.html", "interfaceplplot_1_1plgzax" ],
      [ "plhist", "interfaceplplot_1_1plhist.html", "interfaceplplot_1_1plhist" ],
      [ "plhls", "interfaceplplot_1_1plhls.html", "interfaceplplot_1_1plhls" ],
      [ "plhlsrgb", "interfaceplplot_1_1plhlsrgb.html", "interfaceplplot_1_1plhlsrgb" ],
      [ "plinit", "interfaceplplot_1_1plinit.html", "interfaceplplot_1_1plinit" ],
      [ "pljoin", "interfaceplplot_1_1pljoin.html", "interfaceplplot_1_1pljoin" ],
      [ "pllightsource", "interfaceplplot_1_1pllightsource.html", "interfaceplplot_1_1pllightsource" ],
      [ "pllegend", "interfaceplplot_1_1pllegend.html", "interfaceplplot_1_1pllegend" ],
      [ "plline", "interfaceplplot_1_1plline.html", "interfaceplplot_1_1plline" ],
      [ "plline3", "interfaceplplot_1_1plline3.html", "interfaceplplot_1_1plline3" ],
      [ "pllsty", "interfaceplplot_1_1pllsty.html", "interfaceplplot_1_1pllsty" ],
      [ "plmap", "interfaceplplot_1_1plmap.html", "interfaceplplot_1_1plmap" ],
      [ "plmapline", "interfaceplplot_1_1plmapline.html", "interfaceplplot_1_1plmapline" ],
      [ "plmapfill", "interfaceplplot_1_1plmapfill.html", "interfaceplplot_1_1plmapfill" ],
      [ "plmapstring", "interfaceplplot_1_1plmapstring.html", "interfaceplplot_1_1plmapstring" ],
      [ "plmaptex", "interfaceplplot_1_1plmaptex.html", "interfaceplplot_1_1plmaptex" ],
      [ "plmeridians", "interfaceplplot_1_1plmeridians.html", "interfaceplplot_1_1plmeridians" ],
      [ "plmesh", "interfaceplplot_1_1plmesh.html", "interfaceplplot_1_1plmesh" ],
      [ "plmeshc", "interfaceplplot_1_1plmeshc.html", "interfaceplplot_1_1plmeshc" ],
      [ "plmkstrm", "interfaceplplot_1_1plmkstrm.html", "interfaceplplot_1_1plmkstrm" ],
      [ "plpat", "interfaceplplot_1_1plpat.html", "interfaceplplot_1_1plpat" ],
      [ "plpath", "interfaceplplot_1_1plpath.html", "interfaceplplot_1_1plpath" ],
      [ "plot3d", "interfaceplplot_1_1plot3d.html", "interfaceplplot_1_1plot3d" ],
      [ "plot3dc", "interfaceplplot_1_1plot3dc.html", "interfaceplplot_1_1plot3dc" ],
      [ "plpoin", "interfaceplplot_1_1plpoin.html", "interfaceplplot_1_1plpoin" ],
      [ "plpoin3", "interfaceplplot_1_1plpoin3.html", "interfaceplplot_1_1plpoin3" ],
      [ "plpoly3", "interfaceplplot_1_1plpoly3.html", "interfaceplplot_1_1plpoly3" ],
      [ "plprec", "interfaceplplot_1_1plprec.html", "interfaceplplot_1_1plprec" ],
      [ "plpsty", "interfaceplplot_1_1plpsty.html", "interfaceplplot_1_1plpsty" ],
      [ "plreplot", "interfaceplplot_1_1plreplot.html", "interfaceplplot_1_1plreplot" ],
      [ "plrgb", "interfaceplplot_1_1plrgb.html", "interfaceplplot_1_1plrgb" ],
      [ "plrgb1", "interfaceplplot_1_1plrgb1.html", "interfaceplplot_1_1plrgb1" ],
      [ "plrgbhls", "interfaceplplot_1_1plrgbhls.html", "interfaceplplot_1_1plrgbhls" ],
      [ "plschr", "interfaceplplot_1_1plschr.html", "interfaceplplot_1_1plschr" ],
      [ "plscmap0", "interfaceplplot_1_1plscmap0.html", "interfaceplplot_1_1plscmap0" ],
      [ "plscmap0a", "interfaceplplot_1_1plscmap0a.html", "interfaceplplot_1_1plscmap0a" ],
      [ "plscmap0n", "interfaceplplot_1_1plscmap0n.html", "interfaceplplot_1_1plscmap0n" ],
      [ "plscmap1", "interfaceplplot_1_1plscmap1.html", "interfaceplplot_1_1plscmap1" ],
      [ "plscmap1a", "interfaceplplot_1_1plscmap1a.html", "interfaceplplot_1_1plscmap1a" ],
      [ "plscmap1l", "interfaceplplot_1_1plscmap1l.html", "interfaceplplot_1_1plscmap1l" ],
      [ "plscmap1la", "interfaceplplot_1_1plscmap1la.html", "interfaceplplot_1_1plscmap1la" ],
      [ "plscmap1n", "interfaceplplot_1_1plscmap1n.html", "interfaceplplot_1_1plscmap1n" ],
      [ "plscmap1_range", "interfaceplplot_1_1plscmap1__range.html", "interfaceplplot_1_1plscmap1__range" ],
      [ "plscol0", "interfaceplplot_1_1plscol0.html", "interfaceplplot_1_1plscol0" ],
      [ "plscol0a", "interfaceplplot_1_1plscol0a.html", "interfaceplplot_1_1plscol0a" ],
      [ "plscolbg", "interfaceplplot_1_1plscolbg.html", "interfaceplplot_1_1plscolbg" ],
      [ "plscolbga", "interfaceplplot_1_1plscolbga.html", "interfaceplplot_1_1plscolbga" ],
      [ "plscolor", "interfaceplplot_1_1plscolor.html", "interfaceplplot_1_1plscolor" ],
      [ "plscompression", "interfaceplplot_1_1plscompression.html", "interfaceplplot_1_1plscompression" ],
      [ "plsdidev", "interfaceplplot_1_1plsdidev.html", "interfaceplplot_1_1plsdidev" ],
      [ "plsdimap", "interfaceplplot_1_1plsdimap.html", "interfaceplplot_1_1plsdimap" ],
      [ "plsdiori", "interfaceplplot_1_1plsdiori.html", "interfaceplplot_1_1plsdiori" ],
      [ "plsdiplt", "interfaceplplot_1_1plsdiplt.html", "interfaceplplot_1_1plsdiplt" ],
      [ "plsdiplz", "interfaceplplot_1_1plsdiplz.html", "interfaceplplot_1_1plsdiplz" ],
      [ "plseed", "interfaceplplot_1_1plseed.html", "interfaceplplot_1_1plseed" ],
      [ "plsesc", "interfaceplplot_1_1plsesc.html", "interfaceplplot_1_1plsesc" ],
      [ "plsetmapformc", "interfaceplplot_1_1plsetmapformc.html", "interfaceplplot_1_1plsetmapformc" ],
      [ "plsfam", "interfaceplplot_1_1plsetmapformc_1_1plsfam.html", "interfaceplplot_1_1plsetmapformc_1_1plsfam" ],
      [ "plsfci", "interfaceplplot_1_1plsetmapformc_1_1plsfci.html", "interfaceplplot_1_1plsetmapformc_1_1plsfci" ],
      [ "plsfont", "interfaceplplot_1_1plsetmapformc_1_1plsfont.html", "interfaceplplot_1_1plsetmapformc_1_1plsfont" ],
      [ "plslabelfunc", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc" ],
      [ "plsmaj", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plsmaj.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plsmaj" ],
      [ "plsmin", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plsmin.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plsmin" ],
      [ "plsori", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plsori.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plsori" ],
      [ "plspage", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plspage.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plspage" ],
      [ "plspause", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plspause.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plspause" ],
      [ "plsstrm", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plsstrm.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plsstrm" ],
      [ "plssub", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plssub.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plssub" ],
      [ "plssym", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plssym.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plssym" ],
      [ "plstar", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstar.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstar" ],
      [ "plstransform", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform" ],
      [ "plstripa", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripa.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripa" ],
      [ "plstripd", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripd.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripd" ],
      [ "plstyl", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstyl.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstyl" ],
      [ "plsurf3d", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3d.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3d" ],
      [ "plsurf3dl", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3dl.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3dl" ],
      [ "plstripc", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripc.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripc" ],
      [ "plsvect", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvect.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvect" ],
      [ "plsvect", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvect.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvect" ],
      [ "plsvpa", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvpa.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvpa" ],
      [ "plsxax", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsxax.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsxax" ],
      [ "plsyax", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsyax.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsyax" ],
      [ "plsym", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsym.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsym" ],
      [ "plszax", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plszax.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plszax" ],
      [ "pltext", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1pltext.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1pltext" ],
      [ "plvasp", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plvasp.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plvasp" ],
      [ "plvpas", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plvpas.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plvpas" ],
      [ "plvpor", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plvpor.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plvpor" ],
      [ "plvsta", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plvsta.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plvsta" ],
      [ "plw3d", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plw3d.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plw3d" ],
      [ "plwidth", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plwidth.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plwidth" ],
      [ "plwind", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plwind.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plwind" ],
      [ "plxormod", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plxormod.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plxormod" ]
    ] ],
    [ "strutil.f90", "strutil_8f90.html", [
      [ "plplot_strutils", "classplplot__strutils.html", "classplplot__strutils" ]
    ] ],
    [ "stupidtk.c", "stupidtk_8c.html", "stupidtk_8c" ],
    [ "svg.c", "svg_8c.html", "svg_8c" ],
    [ "tai-utc-gen.c", "tai-utc-gen_8c.html", "tai-utc-gen_8c" ],
    [ "tai-utc.h", "tai-utc_8h.html", "tai-utc_8h" ],
    [ "tclAPI.c", "tclAPI_8c.html", "tclAPI_8c" ],
    [ "tclgen.c", "tclgen_8c.html", "tclgen_8c" ],
    [ "tclgen.h", "tclgen_8h.html", "tclgen_8h" ],
    [ "tclgen_s.h", "tclgen__s_8h.html", "tclgen__s_8h" ],
    [ "tclMain.c", "tclMain_8c.html", "tclMain_8c" ],
    [ "tclMatrix.c", "tclMatrix_8c.html", "tclMatrix_8c" ],
    [ "tclMatrix.h", "tclMatrix_8h.html", "tclMatrix_8h" ],
    [ "TclSup.py", "TclSup_8py.html", "TclSup_8py" ],
    [ "tcpip.c", "tcpip_8c.html", "tcpip_8c" ],
    [ "tcpip.h", "tcpip_8h.html", "tcpip_8h" ],
    [ "test-drv-info.c", "test-drv-info_8c.html", "test-drv-info_8c" ],
    [ "tk.c", "tk_8c.html", "tk_8c" ],
    [ "tkMain.c", "tkMain_8c.html", "tkMain_8c" ],
    [ "tkshell.c", "tkshell_8c.html", "tkshell_8c" ],
    [ "tkwin.c", "tkwin_8c.html", "tkwin_8c" ],
    [ "csa/version.h", "csa_2version_8h.html", "csa_2version_8h" ],
    [ "nn/version.h", "nn_2version_8h.html", "nn_2version_8h" ],
    [ "wingcc.c", "wingcc_8c.html", "wingcc_8c" ],
    [ "wxPLplotstream.cpp", "wxPLplotstream_8cpp.html", null ],
    [ "wxPLplotstream.h", "wxPLplotstream_8h.html", "wxPLplotstream_8h" ],
    [ "wxPLplotwindow.h", "wxPLplotwindow_8h.html", [
      [ "wxPLplotwindow", "classwxPLplotwindow.html", "classwxPLplotwindow" ]
    ] ],
    [ "wxwidgets.cpp", "wxwidgets_8cpp.html", "wxwidgets_8cpp" ],
    [ "wxwidgets.h", "wxwidgets_8h.html", "wxwidgets_8h" ],
    [ "wxwidgets_comms.cpp", "wxwidgets__comms_8cpp.html", null ],
    [ "wxwidgets_comms.h", "wxwidgets__comms_8h.html", "wxwidgets__comms_8h" ],
    [ "wxwidgets_dev.cpp", "wxwidgets__dev_8cpp.html", "wxwidgets__dev_8cpp" ],
    [ "xfig.c", "xfig_8c.html", "xfig_8c" ],
    [ "xwin.c", "xwin_8c.html", "xwin_8c" ]
];